@@ -297,14 +297,14 @@ core.add_thread(function()
             doc.disable_symbols = true
             local filename_message
             if doc.filename then
-              filename_message = "document " .. doc.filename
+              filename_message = doc.filename
             else
-              filename_message = "unnamed document"
+              filename_message = "unnamed"
             end
-            core.status_view:show_message("!", style.accent,
-              "Too many symbols in "..filename_message..
-              ": stopping auto-complete for this document according to "..
-              "config.plugins.autocomplete.max_symbols."
+            core.warn(
+              "Too many symbols in '%s': stopping auto-complete for this document "
+                .. "according to config.plugins.autocomplete.max_symbols.",
+              filename_message
             )
             collectgarbage('collect')
             return {}
@@ -446,6 +446,11 @@ local function update_suggestions()
     end
   end
 
+  -- when triggered manually and first character is a punctuation, it causes
+  -- none of the items to match if they don't also start with the punctuation,
+  -- we remove the punctuations to ensure results with plugins like lsp
+  if triggered_manually then partial = partial:gsub("^%p+", "") end
+
   -- fuzzy match, remove duplicates and store
   items = common.fuzzy_match(items, partial, false)
   local j = 1
@@ -482,7 +487,7 @@ local function get_suggestions_rect(av)
 
   local max_width = 0
   local width_exceeds = false
-  local win_width = system.get_window_size() - style.padding.x  * 2
+  local win_width = system.get_window_size(core.window) - style.padding.x  * 2
   for i, s in ipairs(suggestions) do
     local w = font:get_width(s.text)
     if s.info and not hide_info then
@@ -587,7 +592,7 @@ local function draw_description_box(text, sx, sy, sw, sh)
     previous_scale = SCALE
   end
 
-  local ww = system.get_window_size()
+  local ww = system.get_window_size(core.window)
 
   local font = desc_font
   local lh = font:get_height()
@@ -803,6 +808,7 @@ end
 --
 local on_text_input = RootView.on_text_input
 local on_text_remove = Doc.remove
+local on_doc_close = Doc.on_close
 local update = RootView.update
 local draw = RootView.draw
 
@@ -823,6 +829,11 @@ Doc.remove = function(self, line1, col1, line2, col2)
   end
 end
 
+Doc.on_close = function(self)
+  on_doc_close(self)
+  if cache[self] then cache[self] = nil end
+end
+
 RootView.update = function(...)
   update(...)
 
