@@ -6,6 +6,8 @@ struct RenWindow {
   uint8_t *command_buf;
   size_t command_buf_idx;
   size_t command_buf_size;
+  float scale_x;
+  float scale_y;
 #ifdef PRAGTICAL_USE_SDL_RENDERER
   SDL_Renderer *renderer;
   SDL_Texture *texture;
@@ -19,6 +21,7 @@ void renwin_init_command_buf(RenWindow *ren);
 void renwin_clip_to_surface(RenWindow *ren);
 void renwin_set_clip_rect(RenWindow *ren, RenRect rect);
 void renwin_resize_surface(RenWindow *ren);
+void renwin_update_scale(RenWindow *ren);
 void renwin_show_window(RenWindow *ren);
 void renwin_update_rects(RenWindow *ren, RenRect *rects, int count);
 void renwin_free(RenWindow *ren);
